/*
 *  Copyright (C) 2003 Philip Langdale
 *  Extension of egg_action_group_add_actions which is unattributed
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNgalU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "galeon-action-group.h"
#include "galeon-action.h"
#include "galeon-toggle-action.h"
#include "galeon-radio-action.h"
#include <libgnome/gnome-i18n.h>

/**
 * egg_action_group_add_actions:
 * @action_group: the action group
 * @entries: an array of action descriptions
 * @n_entries: the number of entries
 *
 * This is a convenience routine to create a number of actions and add
 * them to the action group.  Each member of the array describes an
 * action to create.
 */
void
galeon_action_group_add_actions(EggActionGroup *action_group,
				EggActionGroupEntry *entries,
				guint n_entries,
				GaleonWindow *window)
{
  guint i;

  g_return_if_fail (IS_GALEON_WINDOW (window));

  for (i = 0; i < n_entries; i++)
    {
      EggAction *action;
      GType action_type;
      gchar *accel_path;

      switch (entries[i].entry_type) {
      case NORMAL_ACTION:
	action_type = GALEON_TYPE_ACTION;
	break;
      case TOGGLE_ACTION:
	action_type = GALEON_TYPE_TOGGLE_ACTION;
	break;
      case RADIO_ACTION:
	action_type = GALEON_TYPE_RADIO_ACTION;
	break;
      default:
	g_warning ("unsupported action type");
	action_type = GALEON_TYPE_ACTION;
      }

      action = g_object_new (action_type,
			     "name", entries[i].name,
			     "label", _(entries[i].label),
			     "tooltip", _(entries[i].tooltip),
			     "stock_id", entries[i].stock_id,
			     "window", window,
			     NULL);

      if (entries[i].entry_type == RADIO_ACTION &&
	  entries[i].extra_data != NULL)
	{
	  EggAction *radio_action;
	  GSList *group;

	  radio_action =
	    egg_action_group_get_action (EGG_ACTION_GROUP (action_group),
					   entries[i].extra_data);
	  if (radio_action)
	    {
	      group = galeon_radio_action_get_group (GALEON_RADIO_ACTION (radio_action));
	      galeon_radio_action_set_group (GALEON_RADIO_ACTION (action), group);
	    }
	  else
	    g_warning (G_STRLOC " could not look up `%s'", entries[i].extra_data);
	}

      if (entries[i].callback)
	g_signal_connect (action, "activate",
			  entries[i].callback, entries[i].user_data);

      /* set the accel path for the menu item */
      accel_path = g_strconcat ("<Actions>/", action_group->name, "/",
				entries[i].name, NULL);
      if (entries[i].accelerator)
	{
	  guint accel_key = 0;
	  GdkModifierType accel_mods;

	  gtk_accelerator_parse (entries[i].accelerator, &accel_key,
				 &accel_mods);
	  if (accel_key)
	    gtk_accel_map_add_entry (accel_path, accel_key, accel_mods);
	}

      egg_action_set_accel_path (action, accel_path);
      g_free(accel_path);

      egg_action_group_add_action (action_group, action);
      g_object_unref (action);
    }
}
